@@ -288,7 +288,7 @@ class ModelRelationshipSet:
 
     # if modelFrom and modelTo are provided determine that they have specified relationship
     # if only modelFrom, determine that there are relationships present of specified axis
-    def isRelated(self, modelFrom, axis, modelTo=None, visited=None, isDRS=False, consecutiveLinkrole=False): # either model concept or qname
+    def isRelated(self, modelFrom, axis, modelTo=None, visited=None, isDRS=False, consecutiveLinkrole=False) -> bool: # either model concept or qname
         assert self.modelXbrl is not None
         if getattr(self.modelXbrl, "isSupplementalIxdsTarget", False):
             if modelFrom is not None and modelFrom.modelXbrl != self.modelXbrl:
