@@ -207,6 +207,8 @@ class DuplicateFactSet:
         :return: A subset of the facts where the fact of lower precision in every consistent pair has been removed.
         """
         facts = self.deduplicateCompleteSubsets()
+        if len(facts) < 2:
+            return facts
         if not self.areNumeric:
             # Consistency is equivalent to completeness for non-numeric facts
             return facts
@@ -402,7 +404,7 @@ def getAspectEqualFacts(
                 fact.qname,
                 (
                     cast(str, fact.xmlLang or "").lower()
-                    if useLang and fact.concept.type.isWgnStringFactType
+                    if useLang and fact.concept.type.isOimTextFactType
                     else None
                 ),
             )
