@@ -7,7 +7,7 @@ from __future__ import annotations
 import json
 import os
 import zipfile
-from collections import Counter, defaultdict
+from collections import defaultdict
 from dataclasses import dataclass
 from pathlib import Path, PurePosixPath
 from typing import TYPE_CHECKING, Any, cast
@@ -19,13 +19,22 @@ if TYPE_CHECKING:
     from arelle.FileSource import FileSource
 
 
+def pathsContainReportsDirectory(paths: set[str], topLevelDir: str) -> bool:
+    reportDirectory = f"{topLevelDir}/{Const.REPORTS_DIRECTORY}"
+    if reportDirectory in paths:
+        return True
+    reportDirectory = f"{reportDirectory}/"
+    return any(path.startswith(reportDirectory) for path in paths)
+
 def getReportPackageTopLevelDirectory(filesource: FileSource) -> str | None:
     packageEntries = set(filesource.dir or [])
-    potentialTopLevelReportDirs = {
-        topLevelDir
-        for topLevelDir in PackageUtils.getPackageTopLevelDirectories(filesource)
-        if any(f"{topLevelDir}/{path}" in packageEntries for path in Const.REPORT_PACKAGE_PATHS)
-    }
+    potentialTopLevelReportDirs = set()
+    for topLevelDir in PackageUtils.getPackageTopLevelDirectories(filesource):
+        if (
+            f"{topLevelDir}/{Const.REPORT_PACKAGE_FILE}" in packageEntries or
+            pathsContainReportsDirectory(packageEntries, topLevelDir)
+        ):
+            potentialTopLevelReportDirs.add(topLevelDir)
     if len(potentialTopLevelReportDirs) == 1:
         return next(iter(potentialTopLevelReportDirs))
     return None
@@ -98,7 +107,7 @@ def getAllReportEntries(filesource: FileSource, stld: str | None) -> list[Report
     if not isinstance(filesource.fs, zipfile.ZipFile):
         return None
     entries = [f.orig_filename for f in filesource.fs.infolist()]
-    if not any(entry.startswith(f"{stld}/{Const.REPORTS_DIRECTORY}") for entry in entries):
+    if not pathsContainReportsDirectory(set(entries), stld):
         return None
     topReportEntries = []
     entriesBySubDir = defaultdict(list)
@@ -206,15 +215,19 @@ class ReportPackage:
         if reportPackageJsonFile:
             reportPackageJson = getPackageJson(filesource, reportPackageJsonFile)
         reports = getAllReportEntries(filesource, stld)
-        if reportPackageJsonFile is None and reports is None:
+        identifedByInspection = reportPackageJsonFile is not None or reports is not None
+        if reportType == Const.ReportType.UNCONSTRAINED_REPORT_PACKAGE and not identifedByInspection:
+            # A zip file, but not a report package.
             return None
-        reportEntriesBySubDir = Counter(report.dir for report in reports or [] if not report.isTopLevel)
+        if reportType is None:
+            # Archive with unrecognized file extension.
+            if not identifedByInspection:
+                # Not a report package
+                return None
+            # Invalid file extension. Validate as report package and block loading reports.
+            reports = None
         if reports is not None and any(report.isTopLevel for report in reports):
             reports = [report for report in reports if report.isTopLevel]
-        if any(subdirCount > 1 for subdirCount in reportEntriesBySubDir.values()):
-            return None
-        if reportType and reportType.isConstrained and len(reports or []) > 1:
-            return None
         return ReportPackage(
             reportPackageZip=filesource.fs,
             stld=stld,
